use core::str::FromStr;
use serde::Deserialize;
use std::path::PathBuf;
use termion::color::Rgb;

use rhai::Dynamic;
use rhai::Engine;
use rhai::Scope;
use rhai::AST;

pub struct Config<'a> {
    cfg: String,
    eng: Engine,
    pub scope: Scope<'a>,
    ast: AST,
}
impl Config<'static> {
    pub fn new() -> Self {
        let mut engine = Engine::new();
        let mut scope = Scope::new();
        let ast = engine
            .compile_file(PathBuf::from_str("/home/able/Projects/adit/assets/config.rhai").unwrap())
            .unwrap();
        let result = engine.call_fn::<Dynamic>(&mut scope, &ast, "status_bar", ());

        Self {
            cfg: String::new(),
            eng: Engine::new(),
            scope: Scope::new(),
            ast,
        }
    }

    pub fn call(&mut self, fn_name: &str) -> String {
        match self
            .eng
            .call_fn::<String>(&mut self.scope, &self.ast, fn_name, ())
        {
            Ok(string) => string,
            Err(err) => panic!("{}", err),
        }
    }
}
#[derive(Deserialize)]
pub struct RGB(u8, u8, u8);

impl RGB {
    pub fn to_term_color(self) -> Rgb {
        Rgb(self.0, self.1, self.2)
    }
}

#[derive(Deserialize)]
pub struct Theme {
    pub status_fg_color: RGB,
    pub status_bg_color: RGB,
}

impl Theme {
    pub fn default() -> Self {
        Self {
            status_fg_color: RGB(63, 63, 63),
            status_bg_color: RGB(239, 239, 239),
        }
    }
}
